uranography
===========

`uranography` is a collection of classes that supply tools for making
`bokeh` plots of data on the celestial sphere, in various projections.
It is primarily intended for use in interactive environments such as
jupyter notebooks or dashboards.


Contents
--------

.. toctree::
   :maxdepth: 2

   introduction
   installation
   usage
   tutorials
   architecture
   api
